Afinder: find attribute in deep object
========================================

.. code-block:: python

    >>> from afinder import afind
    >>> afind(your_obj, 'something-to-find')
    ['obj.attribute.something', 'obj.attribute.moha:"something is here"']


Installation
------------

To install Afinder, simply:

.. code-block:: bash

    $ pip install afinder
